#[derive(Clone, Debug, Default, Deserialize)]
pub struct GeneralConfig {
    pub prompt: bool
}
